aboutsummaryrefslogtreecommitdiffstats
path: root/src/classes/org/jdesktop/j3d/examples/appearance
diff options
context:
space:
mode:
authorjada <jada@28c7f869-5b4e-e670-f602-82bfaf57f300>2006-03-03 22:02:03 +0000
committerjada <jada@28c7f869-5b4e-e670-f602-82bfaf57f300>2006-03-03 22:02:03 +0000
commit5ac8b22022c4c7401d1df4366da51a882dd4cbcc (patch)
tree97bbabd788f8233630615e9013fd5879458cd89d /src/classes/org/jdesktop/j3d/examples/appearance
parentcc83f56aa28faa7a78b1a1113253619662ef1329 (diff)
1) Updated README-build.html
2) Updated TickTockPicking to use JFrame instead of MainFrame. 3) Removed apimage.jpg and updated programs to stone.jpg instead of apimage.jpg. 4) Modified Dot3Demo to use a compressed image.
Diffstat (limited to 'src/classes/org/jdesktop/j3d/examples/appearance')
-rw-r--r--src/classes/org/jdesktop/j3d/examples/appearance/AppearanceMixed.java8
-rw-r--r--src/classes/org/jdesktop/j3d/examples/appearance/AppearanceTest.java4
2 files changed, 6 insertions, 6 deletions
diff --git a/src/classes/org/jdesktop/j3d/examples/appearance/AppearanceTest.java b/src/classes/org/jdesktop/j3d/examples/appearance/AppearanceTest.java
index f53c24d..fa25921 100644
--- a/src/classes/org/jdesktop/j3d/examples/appearance/AppearanceTest.java
+++ b/src/classes/org/jdesktop/j3d/examples/appearance/AppearanceTest.java
@@ -339,9 +339,9 @@ public class AppearanceTest extends javax.swing.JFrame {
if (texImage == null) {
// the path to the image for an applet
- texImage = Resources.getResource("resources/images/apimage.jpg");
+ texImage = Resources.getResource("resources/images/stone.jpg");
if (texImage == null) {
- System.err.println("resources/images/apimage.jpg not found");
+ System.err.println("resources/images/stone.jpg not found");
System.exit(1);
}
}
diff --git a/src/classes/org/jdesktop/j3d/examples/appearance/AppearanceMixed.java b/src/classes/org/jdesktop/j3d/examples/appearance/AppearanceMixed.java
index b6f76c1..598f5cb 100644
--- a/src/classes/org/jdesktop/j3d/examples/appearance/AppearanceMixed.java
+++ b/src/classes/org/jdesktop/j3d/examples/appearance/AppearanceMixed.java
@@ -451,7 +451,7 @@ public class AppearanceMixed extends javax.swing.JFrame {
}
/**
* Creates new form AppearanceTest
*/
public AppearanceMixed() {
@@ -466,9 +466,9 @@ public class AppearanceMixed extends javax.swing.JFrame {
if (texImage == null) {
// the path to the image for an applet
- texImage = Resources.getResource("resources/images/apimage.jpg");
+ texImage = Resources.getResource("resources/images/stone.jpg");
if (texImage == null) {
- System.err.println("resources/images/apimage.jpg not found");
+ System.err.println("resources/images/stone.jpg not found");
System.exit(1);
}
}
@@ -497,7 +497,7 @@ public class AppearanceMixed extends javax.swing.JFrame {
drawingPanel = new javax.swing.JPanel();
setDefaultCloseOperation(javax.swing.WindowConstants.EXIT_ON_CLOSE);
- setTitle("AppearanceTest");
+ setTitle("AppearanceMixed");
drawingPanel.setLayout(new java.awt.BorderLayout());
drawingPanel.setPreferredSize(new java.awt.Dimension(700, 700));
@@ -451,7 +451,7 @@ public class AppearanceMixed extends javax.swing.JFrame {
}
/**
- * Creates new form AppearanceTest
+ * Creates new form AppearanceMixed
*/
public AppearanceMixed() {